html, body{
  height: 100%;
}

.container-full {
  margin: 0 auto;
  width: 100%;
}

.phone-screen {
	min-height: 8em;
	width: 100%;
	text-align: center;
}
pre.console {
	height: 10em;
	overflow: auto;
}